"""
========================================================================
|                                                                      |
|                       SUSYAI EXAMPLE SCRIPT 03:                      |
|                         PREDICTION FROM FILE                         |
|   ----------------------------------------------------------------   |
|                                                                      |
|   SUSY-AI is a powerful, yet simple interface between SUSY           |
|   data and the sklearn Python class. With the classifier that        |
|   comes with SUSY-AI, it allows for predicting of exclusion of a     |
|   datapoint in pMSSM parameterspace via sklearn using a              |
|   pre-trained classifier in only a couple of commands.               |
|                                                                      |
|   Full documentation, and the most recent version of the software    |
|   can be found on the project website                                |
|                                                                      |
|       https://susyai.hepforge.org/                                   |
|                                                                      |
|   If you are using this script scientifically or commercially,       |
|   please reference the following paper                               |
|                                                                      |
|       Sascha Caron, Jong Soo Kim, Krzysztof Rolbiecki, Roberto       |
|       Ruiz de Austri, Bob Stienen, 'The BSM-AI project: SUSY-AI -    |
|       Generalizing LHC limits on Supersymmetry with Machine          |
|       Learning'. arXiv: 1605.02797 [hep-ph]                          |
|                                                                      |
|   For questions about the script, contact                            |
|                                                                      |
|       Bob Stienen <b.stienen@student.ru.nl>                          |
|                                                                      |
========================================================================
"""


from susyai import susyai
import numpy as np

# Define file
# This has to be a list, even though it is just a single file!
files = ['spectrumfiles/spectrum_01.slha']


# Creating susyai object
sa = susyai()

# Set the location of the pickle to a valid location before testing
# Loading before prediction removes the need for it during prediction, thus speeding it up
sa.set_pickle_location("pmssm.pkl")
sa.load_pickle()

# Set coordinate selection to preset-1
sa.set_coordinate_selector(1)

# Prediction
clas, pred, conf, coords = sa.predict_files(files)

print("classification: ",clas)
print("prediction:     ",pred)
print("confidence:     ",conf)
