"""
========================================================================
|                                                                      |
|                       SUSYAI EXAMPLE SCRIPT 07:                      |
|                      EXTRA INFORMATION SELECTOR                      |
|   ----------------------------------------------------------------   |
|                                                                      |
|   SUSY-AI is a powerful, yet simple interface between SUSY           |
|   data and the sklearn Python class. With the classifier that        |
|   comes with SUSY-AI, it allows for predicting of exclusion of a     |
|   datapoint in pMSSM parameterspace via sklearn using a              |
|   pre-trained classifier in only a couple of commands.               |
|                                                                      |
|   Full documentation, and the most recent version of the software    |
|   can be found on the project website                                |
|                                                                      |
|       https://susyai.hepforge.org/                                   |
|                                                                      |
|   If you are using this script scientifically or commercially,       |
|   please reference the following paper                               |
|                                                                      |
|       Sascha Caron, Jong Soo Kim, Krzysztof Rolbiecki, Roberto       |
|       Ruiz de Austri, Bob Stienen, 'The BSM-AI project: SUSY-AI -    |
|       Generalizing LHC limits on Supersymmetry with Machine          |
|       Learning'. arXiv: 1605.02797 [hep-ph]                          |
|                                                                      |
|   For questions about the script, contact                            |
|                                                                      |
|       Bob Stienen <b.stienen@student.ru.nl>                          |
|                                                                      |
========================================================================
"""

from susyai import susyai
import numpy as np

# Define file
# This has to be a list, even though it is just a single file!
files = ['spectrumfiles/spectrum_01.slha']

# Define xtra selection function
# The xtra selector function must take two arguments:
#   a PYSLHA DOC object and
#   a string containing the path to the file
# The xtra selector has to return the data in the form of a NUMPY NDARRAY of shape (N,)
#   where N can be any integer the user wants, as long as it does not change in a single run
# This particular function selects the mass of the gluino and ~chi01 particles
def xsel(spectrum, filepath):
	x = np.zeros(2)
	x[0] = spectrum.blocks['MASS'][1000021]      # mass_g
	x[1] = spectrum.blocks['MASS'][1000022]      # ~chi_01
	return x

# Creating susyai object
sa = susyai()

# Set the location of the pickle to a valid location before testing
# Loading before prediction removes the need for it during prediction, thus speeding it up
sa.set_pickle_location("pmssm.pkl")
sa.load_pickle()

# Set coordinate selection to preset-1
sa.set_coordinate_selector(1)

# Set xtra selector to userdefined function xsel
sa.set_xtra_selector(xsel)

# Prediction
clas, pred, conf, coord, xtra = sa.predict_files(files)

print("classification: ",clas)
print("prediction:     ",pred)
print("confidence:     ",conf)
print("xtra:           ",xtra)
